##DocumentationforAPIEndpoints

AllURIsarerelativeto*https://hostname:443*

|Method|HTTPrequest|Description
------------|-------------|-------------|-------------
*DefaultApi*|[**add_ad_hoc_task**](DefaultApi.md#add_ad_hoc_task)|**POST**/inv-playbook/task/add/{investigationId}|Addad-hoctask
*DefaultApi*|[**close_incidents_batch**](DefaultApi.md#close_incidents_batch)|**POST**/incident/batchClose|Batchcloseincidents
*DefaultApi*|[**complete_task**](DefaultApi.md#complete_task)|**POST**/inv-playbook/task/complete|[Deprecated]Completeatask
*DefaultApi*|[**complete_task_v2**](DefaultApi.md#complete_task_v2)|**POST**/v2/inv-playbook/task/complete|Completeatask
*DefaultApi*|[**copy_script**](DefaultApi.md#copy_script)|**POST**/automation/copy|Copyautomation
*DefaultApi*|[**create_docker_image**](DefaultApi.md#create_docker_image)|**POST**/settings/docker-images|CreateImage
*DefaultApi*|[**create_incident**](DefaultApi.md#create_incident)|**POST**/incident|Createsingleincident
*DefaultApi*|[**create_incident_json**](DefaultApi.md#create_incident_json)|**POST**/incident/json|CreateincidentfromJSON
*DefaultApi*|[**create_incidents_batch**](DefaultApi.md#create_incidents_batch)|**POST**/incident/batch|Batchcreateincidents
*DefaultApi*|[**create_or_update_incident_type**](DefaultApi.md#create_or_update_incident_type)|**POST**/incidenttype|CreatenewIncidentType
*DefaultApi*|[**delete_ad_hoc_task**](DefaultApi.md#delete_ad_hoc_task)|**POST**/inv-playbook/task/delete/{investigationId}/{invPBTaskId}|Deletead-hoctask
*DefaultApi*|[**delete_automation_script**](DefaultApi.md#delete_automation_script)|**POST**/automation/delete|Deleteexistingautomation
*DefaultApi*|[**delete_evidence_op**](DefaultApi.md#delete_evidence_op)|**POST**/evidence/delete|deleteevidence
*DefaultApi*|[**delete_incidents_batch**](DefaultApi.md#delete_incidents_batch)|**POST**/incident/batchDelete|Batchdeleteincidents
*DefaultApi*|[**delete_indicators_batch**](DefaultApi.md#delete_indicators_batch)|**POST**/indicators/batchDelete|Batchwhitelistordeleteindicators
*DefaultApi*|[**delete_widget**](DefaultApi.md#delete_widget)|**DELETE**/widgets/{id}|Removeexistingwidget
*DefaultApi*|[**download_file**](DefaultApi.md#download_file)|**GET**/entry/download/{entryid}|Downloadfile
*DefaultApi*|[**download_latest_report**](DefaultApi.md#download_latest_report)|**GET**/reports/{id}/latest|GetlatestreportbyID
*DefaultApi*|[**edit_ad_hoc_task**](DefaultApi.md#edit_ad_hoc_task)|**POST**/inv-playbook/task/edit/{investigationId}|Editad-hoctask
*DefaultApi*|[**entry_export_artifact**](DefaultApi.md#entry_export_artifact)|**POST**/entry/exportArtifact|ExportArtifact
*DefaultApi*|[**execute_report**](DefaultApi.md#execute_report)|**POST**/report/{id}/{requestId}/execute|Executereport
*DefaultApi*|[**export_incidents_to_csv_batch**](DefaultApi.md#export_incidents_to_csv_batch)|**POST**/incident/batch/exportToCsv|Batchexportincidentstocsv
*DefaultApi*|[**export_indicators_to_csv_batch**](DefaultApi.md#export_indicators_to_csv_batch)|**POST**/indicators/batch/exportToCsv|Batchexportindicatorstocsv
*DefaultApi*|[**export_indicators_to_stix_batch**](DefaultApi.md#export_indicators_to_stix_batch)|**POST**/indicators/batch/export/stix|BatchexportindicatorstoSTIX
*DefaultApi*|[**get_all_reports**](DefaultApi.md#get_all_reports)|**GET**/reports|Getallreports
*DefaultApi*|[**get_all_widgets**](DefaultApi.md#get_all_widgets)|**GET**/widgets|
*DefaultApi*|[**get_audits**](DefaultApi.md#get_audits)|**POST**/settings/audits|GetAudits
*DefaultApi*|[**get_automation_scripts**](DefaultApi.md#get_automation_scripts)|**POST**/automation/search|SearchAutomation(akascripts)
*DefaultApi*|[**get_docker_images**](DefaultApi.md#get_docker_images)|**GET**/settings/docker-images|GetDockerImages
*DefaultApi*|[**get_entry_artifact**](DefaultApi.md#get_entry_artifact)|**GET**/entry/artifact/{id}|Getentryartifact
*DefaultApi*|[**get_incident_as_csv**](DefaultApi.md#get_incident_as_csv)|**GET**/incident/csv/{id}|GetincidentasCSV
*DefaultApi*|[**get_incidents_fields_by_incident_type**](DefaultApi.md#get_incidents_fields_by_incident_type)|**GET**/incidentfields/associatedTypes/{type}|Getallincidentfieldsassociatedwithincidenttype
*DefaultApi*|[**get_indicators_as_csv**](DefaultApi.md#get_indicators_as_csv)|**GET**/indicators/csv/{id}|GetindicatorsasCSV
*DefaultApi*|[**get_indicators_as_stix**](DefaultApi.md#get_indicators_as_stix)|**GET**/indicators/stix/v2/{id}|GetindicatorsasSTIXV2
*DefaultApi*|[**get_report_by_id**](DefaultApi.md#get_report_by_id)|**GET**/reports/{id}|GetreportbyID
*DefaultApi*|[**get_stats_for_dashboard**](DefaultApi.md#get_stats_for_dashboard)|**POST**/statistics/dashboards/query|GetDashboardStatistics
*DefaultApi*|[**get_stats_for_widget**](DefaultApi.md#get_stats_for_widget)|**POST**/statistics/widgets/query|GetWidgetStatistics
*DefaultApi*|[**get_widget**](DefaultApi.md#get_widget)|**GET**/widgets/{id}|GetwidgetbyID
*DefaultApi*|[**import_classifier**](DefaultApi.md#import_classifier)|**POST**/classifier/import|Importaclassifier
*DefaultApi*|[**import_dashboard**](DefaultApi.md#import_dashboard)|**POST**/dashboards/import|Importadashboard
*DefaultApi*|[**import_incident_fields**](DefaultApi.md#import_incident_fields)|**POST**/incidentfields/import|Importanincidentsfield
*DefaultApi*|[**import_incident_types_handler**](DefaultApi.md#import_incident_types_handler)|**POST**/incidenttypes/import|Importanincidenttype
*DefaultApi*|[**import_layout**](DefaultApi.md#import_layout)|**POST**/v2/layouts/import|Importalayout
*DefaultApi*|[**import_playbook**](DefaultApi.md#import_playbook)|**POST**/playbook/save/yaml|Importandoverrideplaybook
*DefaultApi*|[**import_script**](DefaultApi.md#import_script)|**POST**/automation/import|Uploadanautomation
*DefaultApi*|[**import_widget**](DefaultApi.md#import_widget)|**POST**/widgets/import|Importawidget
*DefaultApi*|[**incident_file_upload**](DefaultApi.md#incident_file_upload)|**POST**/incident/upload/{id}|
*DefaultApi*|[**indicator_whitelist**](DefaultApi.md#indicator_whitelist)|**POST**/indicator/whitelist|WhitelistsordeletesIndicator
*DefaultApi*|[**indicators_create**](DefaultApi.md#indicators_create)|**POST**/indicator/create|CreateIndicator
*DefaultApi*|[**indicators_create_batch**](DefaultApi.md#indicators_create_batch)|**POST**/indicators/upload|Createindicators
*DefaultApi*|[**indicators_edit**](DefaultApi.md#indicators_edit)|**POST**/indicator/edit|EditIndicator
*DefaultApi*|[**indicators_search**](DefaultApi.md#indicators_search)|**POST**/indicators/search|Searchindicators
*DefaultApi*|[**integration_upload**](DefaultApi.md#integration_upload)|**POST**/settings/integration-conf/upload|Uploadanintegration
*DefaultApi*|[**investigation_add_entries_sync**](DefaultApi.md#investigation_add_entries_sync)|**POST**/entry/execute/sync|Createnewentryinexistinginvestigation
*DefaultApi*|[**investigation_add_entry_handler**](DefaultApi.md#investigation_add_entry_handler)|**POST**/entry|Createnewentryinexistinginvestigation
*DefaultApi*|[**investigation_add_formatted_entry_handler**](DefaultApi.md#investigation_add_formatted_entry_handler)|**POST**/entry/formatted|Createnewformattedentryinexistinginvestigation
*DefaultApi*|[**revoke_user_api_key**](DefaultApi.md#revoke_user_api_key)|**POST**/apikeys/revoke/user/{username}|
*DefaultApi*|[**save_evidence**](DefaultApi.md#save_evidence)|**POST**/evidence|Saveevidence
*DefaultApi*|[**save_or_update_script**](DefaultApi.md#save_or_update_script)|**POST**/automation|Createorupdateautomation
*DefaultApi*|[**save_widget**](DefaultApi.md#save_widget)|**POST**/widgets|Addorupdateawidget
*DefaultApi*|[**search_evidence**](DefaultApi.md#search_evidence)|**POST**/evidence/search|Searchevidence
*DefaultApi*|[**search_incidents**](DefaultApi.md#search_incidents)|**POST**/incidents/search|Searchincidentsbyfilter
*DefaultApi*|[**search_investigations**](DefaultApi.md#search_investigations)|**POST**/investigations/search|Searchinvestigationsbyfilter
*DefaultApi*|[**simple_complete_task**](DefaultApi.md#simple_complete_task)|**POST**/inv-playbook/task/complete/simple|Completetasksimple(nofile)
*DefaultApi*|[**submit_task_form**](DefaultApi.md#submit_task_form)|**POST**/v2/inv-playbook/task/form/submit|Completeatask
*DefaultApi*|[**task_add_comment**](DefaultApi.md#task_add_comment)|**POST**/inv-playbook/task/note/add|Taskaddcomment
*DefaultApi*|[**task_assign**](DefaultApi.md#task_assign)|**POST**/inv-playbook/task/assign|Assigntask
*DefaultApi*|[**task_set_due**](DefaultApi.md#task_set_due)|**POST**/inv-playbook/task/due|Settaskduedate
*DefaultApi*|[**task_un_complete**](DefaultApi.md#task_un_complete)|**POST**/inv-playbook/task/uncomplete|Uncompleteatask
*DefaultApi*|[**update_entry_note**](DefaultApi.md#update_entry_note)|**POST**/entry/note|Markentryasnote
*DefaultApi*|[**update_entry_tags_op**](DefaultApi.md#update_entry_tags_op)|**POST**/entry/tags|Setentrytags


##DocumentationForModels

-[AdvanceArg](AdvanceArg.md)
-[ArgAtomicFilter](ArgAtomicFilter.md)
-[ArgFilter](ArgFilter.md)
-[ArgTransformer](ArgTransformer.md)
-[Argument](Argument.md)
-[ArrayPositions](ArrayPositions.md)
-[Attachment](Attachment.md)
-[Audit](Audit.md)
-[AuditResult](AuditResult.md)
-[AutomationScript](AutomationScript.md)
-[AutomationScriptAPI](AutomationScriptAPI.md)
-[AutomationScriptFilter](AutomationScriptFilter.md)
-[AutomationScriptFilterWrapper](AutomationScriptFilterWrapper.md)
-[AutomationScriptResult](AutomationScriptResult.md)
-[Command](Command.md)
-[CommonFields](CommonFields.md)
-[ComplexArg](ComplexArg.md)
-[ConfigDataType](ConfigDataType.md)
-[ConfigField](ConfigField.md)
-[CreateIncidentRequest](CreateIncidentRequest.md)
-[CustomFields](CustomFields.md)
-[DBotScore](DBotScore.md)
-[Dashboard](Dashboard.md)
-[DataCollectionForm](DataCollectionForm.md)
-[DateRange](DateRange.md)
-[DateRangeFilter](DateRangeFilter.md)
-[DeleteEvidence](DeleteEvidence.md)
-[DockerImage](DockerImage.md)
-[DockerImagesResult](DockerImagesResult.md)
-[DownloadEntry](DownloadEntry.md)
-[Duration](Duration.md)
-[EndingType](EndingType.md)
-[Entry](Entry.md)
-[EntryCategory](EntryCategory.md)
-[EntryHistory](EntryHistory.md)
-[EntryReputation](EntryReputation.md)
-[EntryTask](EntryTask.md)
-[EntryType](EntryType.md)
-[Evidence](Evidence.md)
-[EvidenceData](EvidenceData.md)
-[Evidences](Evidences.md)
-[EvidencesFilterWrapper](EvidencesFilterWrapper.md)
-[EvidencesSearchResponse](EvidencesSearchResponse.md)
-[ExpirationPolicy](ExpirationPolicy.md)
-[ExpirationSettingsSource](ExpirationSettingsSource.md)
-[ExpirationSource](ExpirationSource.md)
-[FeedIndicator](FeedIndicator.md)
-[FeedIndicators](FeedIndicators.md)
-[FieldGroup](FieldGroup.md)
-[FieldMapping](FieldMapping.md)
-[FieldTermLocationMap](FieldTermLocationMap.md)
-[FileMetadata](FileMetadata.md)
-[FilterCache](FilterCache.md)
-[FilterOperatorID](FilterOperatorID.md)
-[FormDisplay](FormDisplay.md)
-[GenericIndicatorUpdateBatch](GenericIndicatorUpdateBatch.md)
-[GenericStringDateFilter](GenericStringDateFilter.md)
-[GenericStringFilter](GenericStringFilter.md)
-[GridColumn](GridColumn.md)
-[Group](Group.md)
-[Groups](Groups.md)
-[HumanCron](HumanCron.md)
-[Important](Important.md)
-[Incident](Incident.md)
-[IncidentField](IncidentField.md)
-[IncidentFilter](IncidentFilter.md)
-[IncidentSearchResponseWrapper](IncidentSearchResponseWrapper.md)
-[IncidentStatus](IncidentStatus.md)
-[IncidentType](IncidentType.md)
-[IncidentWrapper](IncidentWrapper.md)
-[Incidents](Incidents.md)
-[IndicatorContext](IndicatorContext.md)
-[IndicatorEditBulkResponse](IndicatorEditBulkResponse.md)
-[IndicatorFilter](IndicatorFilter.md)
-[IndicatorResult](IndicatorResult.md)
-[InlineResponse200](InlineResponse200.md)
-[InsightCache](InsightCache.md)
-[InstanceClassifier](InstanceClassifier.md)
-[IntegrationScript](IntegrationScript.md)
-[InvPlaybookAssignee](InvPlaybookAssignee.md)
-[InvPlaybookDue](InvPlaybookDue.md)
-[InvPlaybookTaskCompleteData](InvPlaybookTaskCompleteData.md)
-[InvPlaybookTaskData](InvPlaybookTaskData.md)
-[InvTaskInfo](InvTaskInfo.md)
-[Investigation](Investigation.md)
-[InvestigationFilter](InvestigationFilter.md)
-[InvestigationPlaybook](InvestigationPlaybook.md)
-[InvestigationPlaybookData](InvestigationPlaybookData.md)
-[InvestigationPlaybookState](InvestigationPlaybookState.md)
-[InvestigationPlaybookTask](InvestigationPlaybookTask.md)
-[InvestigationPlaybookTasksAPI](InvestigationPlaybookTasksAPI.md)
-[InvestigationSearchResponse](InvestigationSearchResponse.md)
-[InvestigationStatus](InvestigationStatus.md)
-[InvestigationType](InvestigationType.md)
-[Investigations](Investigations.md)
-[IocObject](IocObject.md)
-[IocObjects](IocObjects.md)
-[Label](Label.md)
-[Layout](Layout.md)
-[LayoutAPI](LayoutAPI.md)
-[LayoutField](LayoutField.md)
-[LayoutSection](LayoutSection.md)
-[Location](Location.md)
-[Locations](Locations.md)
-[Mapper](Mapper.md)
-[ModuleArgs](ModuleArgs.md)
-[ModuleConfiguration](ModuleConfiguration.md)
-[NewDockerImage](NewDockerImage.md)
-[NewDockerImageResult](NewDockerImageResult.md)
-[NotifiableItem](NotifiableItem.md)
-[NotifyTimings](NotifyTimings.md)
-[OperatorArgument](OperatorArgument.md)
-[Order](Order.md)
-[Output](Output.md)
-[OutputType](OutputType.md)
-[Period](Period.md)
-[Playbook](Playbook.md)
-[PlaybookInput](PlaybookInput.md)
-[PlaybookInputs](PlaybookInputs.md)
-[PlaybookOutput](PlaybookOutput.md)
-[PlaybookOutputs](PlaybookOutputs.md)
-[PlaybookTask](PlaybookTask.md)
-[PlaybookView](PlaybookView.md)
-[Question](Question.md)
-[QuietMode](QuietMode.md)
-[RawMessage](RawMessage.md)
-[Reliability](Reliability.md)
-[RemoteRepos](RemoteRepos.md)
-[Report](Report.md)
-[ReportAutomation](ReportAutomation.md)
-[ReportFieldsDecoder](ReportFieldsDecoder.md)
-[ReportQuery](ReportQuery.md)
-[ReputationCalcAlg](ReputationCalcAlg.md)
-[ReputationData](ReputationData.md)
-[RunStatus](RunStatus.md)
-[SLA](SLA.md)
-[SLAState](SLAState.md)
-[ScriptAPI](ScriptAPI.md)
-[ScriptSubType](ScriptSubType.md)
-[ScriptTarget](ScriptTarget.md)
-[ScriptType](ScriptType.md)
-[SearchIncidentsData](SearchIncidentsData.md)
-[Section](Section.md)
-[SectionItem](SectionItem.md)
-[Severity](Severity.md)
-[StatsQueryResponse](StatsQueryResponse.md)
-[StatsTextResponse](StatsTextResponse.md)
-[StatsTrendsResponse](StatsTrendsResponse.md)
-[System](System.md)
-[SystemAgent](SystemAgent.md)
-[Task](Task.md)
-[TaskCondition](TaskCondition.md)
-[TaskLoop](TaskLoop.md)
-[TaskState](TaskState.md)
-[TaskType](TaskType.md)
-[TaskView](TaskView.md)
-[TermLocationMap](TermLocationMap.md)
-[TerminalOptions](TerminalOptions.md)
-[TimerAction](TimerAction.md)
-[TimerTrigger](TimerTrigger.md)
-[TransformerOperatorID](TransformerOperatorID.md)
-[UpdateDataBatch](UpdateDataBatch.md)
-[UpdateEntry](UpdateEntry.md)
-[UpdateEntryTags](UpdateEntryTags.md)
-[UpdateIndicatorReputationData](UpdateIndicatorReputationData.md)
-[UpdateResponse](UpdateResponse.md)
-[UploadedEntry](UploadedEntry.md)
-[Version](Version.md)
-[Widget](Widget.md)
-[WidgetCell](WidgetCell.md)
-[WidgetCells](WidgetCells.md)


##DocumentationForAuthorization


##api_key

-**Type**:APIkey
-**APIkeyparametername**:Authorization
-**Location**:HTTPheader

##csrf_token

-**Type**:APIkey
-**APIkeyparametername**:X-XSRF-TOKEN
-**Location**:HTTPheader


##Author



